@@ -6,15 +6,42 @@ use warnings;
 use Moo;
 use Catmandu::Sane;
 
+use Data::Dumper qw(Dumper);
+
 use Catmandu::Store::CA::Bag;
 
 with 'Catmandu::Store';
 
-has url      => (is => 'ro', required => 1);
-has username => (is => 'ro', required => 1);
-has password => (is => 'ro', required => 1);
-has model    => (is => 'ro', default => 'ca_objects');
+has url         => (is => 'ro', required => 1);
+has username    => (is => 'ro', required => 1);
+has password    => (is => 'ro', required => 1);
+has model       => (is => 'ro', default => 'ca_objects');
+has lang        => (is => 'ro', default => 'nl_NL');
+has _field_list => (is => 'rw', default => sub { return []; });
 
+sub BUILDARGS {
+    my ($class, %args) = @_;
+
+    my $field_list = delete $args{'field_list'};
+
+    if ($field_list) {
+        my @list = split(/,/, $field_list);
+        my @fields = map { $_ =~ s/^\s+//; $_; } @list;
+        $args{'_field_list'} = \@fields;
+    }
+    return \%args;
+}
+
+sub field_list {
+    my ($self, $field_list) = @_;
+    if ($field_list) {
+        my @list = split(/,/, $field_list);
+        my @fields = map { $_ =~ s/^\s+//; $_; } @list;
+        $self->_field_list = \@fields;
+    } else {
+        return join(',', @{$self->_field_list});
+    }
+}
 
 1;
 __END__
@@ -27,7 +54,7 @@ Catmandu::Store::CA - Retrieve items from a L<CollectiveAccess|http://collective
 =head1 SYNOPSIS
 
     # From the command line
-    catmandu export CA to YAML --id 1234 --username demo --password demo --url http://demo.collectiveaccess.org --model ca_objects
+    catmandu export CA to YAML --id 1234 --username demo --password demo --url http://demo.collectiveaccess.org --model ca_objects --lang nl_NL --field_list 'ca_entities, preferred_labels'
 
     # From a Catmandu Fix
     lookup_in_store(
@@ -36,17 +63,21 @@ Catmandu::Store::CA - Retrieve items from a L<CollectiveAccess|http://collective
       url: http://demo.collectiveaccess.org,
       username: demo,
       password: demo,
-      model: ca_objects
+      model: ca_objects,
+      lang: nl_NL,
+      field_list: 'ca_entities, preferred_labels'
     )
 
     # From Perl code
     use Catmandu;
 
     my $store = Catmandu->store('CA',
-        username => 'demo',
-        password => 'demo',
-        url      => 'http://demo.collectiveaccess.org',
-        model    => 'ca_objects'
+        username   => 'demo',
+        password   => 'demo',
+        url        => 'http://demo.collectiveaccess.org',
+        model      => 'ca_objects',
+        lang       => 'nl_NL',
+        field_list => 'ca_entities, preferred_labels'
     )->bag;
 
     my $item = $store->get('1234');
@@ -99,6 +130,17 @@ The model is by default C<ca_objects>, but the following are also supported:
 
 =back
 
+=head2 lang
+
+The language (locale) in which to return the data. Set to C<nl_NL> by default,
+will automatically fall back to C<en_US> if the attribute does not exist in the
+selected locale. Use the L<IETF language tag|https://en.wikipedia.org/wiki/IETF_language_tag>.
+
+=head2 field_list
+
+A comma-separated, quoted, (C<'foo, bar'>) list of fields that the CollectiveAccess
+API should return. Is optional and can be left empty to return the default 'summary'.
+
 =head1 METHODS
 
 =head2 new(%configuration)
